#
# spec file for package qtractor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qtractor
Version:        1.1.1
Release:        1.2
Summary:        An Audio/MIDI multi-track sequencer
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://qtractor.org/
Source0:        https://download.sourceforge.net/qtractor/qtractor-%{version}.tar.gz
Source1:        https://download.sf.net/qtractor/qtractor-manual-and-howtos.pdf
BuildRequires:  alsa-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  dssi-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa-devel
BuildRequires:  libjack-devel
BuildRequires:  liblo-devel
BuildRequires:  librubberband-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel >= 1.0.11
BuildRequires:  libvorbis-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(aubio)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(lilv-0)
BuildRequires:  pkgconfig(lv2)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(suil-0)
BuildRequires:  pkgconfig(xcb)
Recommends:     %{name}-doc-pdf

%description
Qtractor is an Audio/MIDI multi-track sequencer application
written in C++ around the Qt6 toolkit.

The initial target platform will be Linux, where the Jack Audio
Connection Kit (JACK) for audio, and the Advanced Linux Sound
Architecture (ALSA) for MIDI, are the main infrastructures to
evolve as a fairly-featured Linux Desktop Audio Workstation GUI,
specially dedicated to the personal home-studio.

%package doc-pdf
Summary:        Documentation for Qtractor
BuildArch:      noarch

%description doc-pdf
This package contains qtractor-manual-and-howtos.pdf
For your reading

%prep
%setup -q
cp -v %{S:1} qtractor-manual-and-howtos.pdf

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}
mv %{buildroot}%{_libdir}/qtractor/qtractor_plugin_scan %{buildroot}%{_bindir}
mv %{buildroot}%{_datadir}/qtractor/palette/"Wonton Soup.conf" %{buildroot}%{_datadir}/qtractor/palette/Wonton_Soup.conf

%files
%doc ChangeLog README
%license LICENSE
%dir %{_datadir}/metainfo/
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%dir %{_datadir}/qtractor/audio
%dir %{_datadir}/qtractor/instruments
%dir %{_datadir}/qtractor/palette
%{_bindir}/%{name}
%{_bindir}/qtractor_plugin_scan
%{_datadir}/applications/org.rncbc.qtractor.desktop
%{_datadir}/metainfo/org.rncbc.qtractor.metainfo.xml
%{_datadir}/icons/*/*/apps/org.rncbc.qtractor*
%{_datadir}/icons/*/*/mimetypes/org.rncbc.qtractor.*
%{_datadir}/mime/packages/org.rncbc.qtractor.xml
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/fr/man1/%{name}.1%{?ext_man}
%{_datadir}/%{name}/translations/*
%{_datadir}/qtractor/audio/metro_bar.wav
%{_datadir}/qtractor/audio/metro_beat.wav
%{_datadir}/qtractor/instruments/Standard1.ins
%{_datadir}/qtractor/palette/KXStudio.conf
%{_datadir}/qtractor/palette/Wonton_Soup.conf

%files doc-pdf
%doc qtractor-manual-and-howtos.pdf

%changelog
* Sun Aug 25 2024 hui <sturm-fr@web.de>
- update to 1.1.1:
  * Fixed an incredibly severe bug, introduced very recently, that deletes all MIDI files belonging to active clips, when closing and discarding a       modified session without saving.
  * Fixed MIDI clip recording when note-off events are missing or not transmitted.
  * Fixed a relatively old crash-bug that manifests on undoing several free-hand drawn events (Edit/Select Mode/Edit Draw) in the MIDI clip editor       (aka. piano-roll).
- update to 1.1.0:
  * Fixed MIDI clip step-input when play-head is located beyond or after the end of the active looping/cycle range.
  * ixed whole clip selection, implied after dragging the lasso over the left and before the beginning of timeline.
  * Clip/Unlink is now a undo/redo-able command.
  * All sessions now honor their designated resolution property (PPQN aka. ticks-per-beat) not subordinated to former ALSA sequencer queue anymore,     which runs on a higher resolution still.
  * Avoid removing MIDI Track/Channel tree items from the Files view (eg. via direct [Del] keyboard shortcut when in focus).
  * Fixed a probable old issue of spilled and duplicated shortcut entries (Help/Shortcuts...) between main tracks/timeline and MIDI clip editor         (aka. piano-roll) windows.
  * Fixed fade-in/out curve types of clips when copy-pasted over the main tracks timeline.
  * Fixed general plugin scan/cache optimization in face of new plugins added and/or removed.
  * Fixed VST3 Plug-in main/active buses channel count inventory; also, on updating host parameters, only save and load custom modified parameter       values from current state.
  * Fixed a misssing display and port-name filtering issue, that was introduced recently to the MIDI Connections widget only.
* Tue Jun 25 2024 Dave Plater <davejplater@gmail.com>
- Happy first birthday qtractor version 1.0.0
- 1.0.0  2024-06-21  An Unthinkable Release.
- Making up the unthinkable (aka. v1.0.0)
- General plugin scan/cache optimization.
- Improved legibility to all clip title labels (color contrast).
- Save/load the correct order and labeling of audio/MIDI send/
  /return pseudo-plugin inserts.
- Fixed a display and port-name filtering issue that was present
  ever since on the Connections widget.
* Sun Oct 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.35:
  * MIDI Step-input is now finally featured on the MIDI clip
    editor (aka. piano-roll), provided Clip/Record is on and playback
    is not rolling; current snap-to-beat applies; starts/resets to
    play-head;
  * Edit/Insert/Step to advance a single step/rest.
  * Notes keyed in the MIDI clip editor's virtual piano keyboard
    may now be recorded, especially while "overdubbing".
  * The official VST3 plug-in SDK is now included in the source
    tree as Git submodules.
  * Fixed a rounding error on current BBT information passed to
    plugins and to JACK transport/timebase.
  * When on Track/Auto Deactivate mode, plugins now show a dull,
    dimmed lit, green (fake-)LED when in auto-deactivated state.
  * Attempt to actually (de)activate plugins once on
    (de)instantiation.
  * Fixed the snap-to-beat of new notes entry on the MIDI clip
    editor (aka. piano-roll) due on time signature changes.
  * Start JACK transport rolling only when metronome Count-in
    ends.
  * Fixed an allegedly old and incorrect 0dBfs notch position on
    MIDI track/buses audio meter sidekicks.
  * Send/return and Aux-send inserts now show the proper name and
    the target output bus name on the properties editor title
    respectively.
  * Fixed a zero-day blunder that was keeping the real-time
    process cycle from having the uniform block-size of 64 frames per
    period;
  * Multiple MIDI clip tools may now be applied simultaneously,
    in a single shot, in the following priority order: quantize,
    transpose, normalize, resize, rescale and timeshift.
  * Plugin inventory scan now slightly optimized to an allegedly
    lesser aggressive cache-invalidation algorithm.
  * Do not send/Preview notes on the MIDI clip editor (aka.
    piano-roll) when playback is currently rolling.
  * Send all pending MIDI Note-Off events when playback
    stops/shuts-off
  * Fixed the internal MIDI file player queue to the highest
    resolution possible (PPQN aka ticks-per-beat).
  * Fixed MIDI recording delay and recorded clip lengths when
    metronome Count-in is in effect for recording.
* Thu Apr  6 2023 Christophe Marin <christophe@krop.fr>
- Spec cleanup: remove obsolete conditions
* Mon Mar 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.32:
  * Downgraded JACK timebase BBT information to nominal PPQN
    resolution (aka. ticks-per-beat).
  * Make sure all previously saved connections to identical ALSA
    MIDI hardware devices are now discriminated and properly
    restored, even though the target deviceds have the very same
    name.
  * Fix drag'n'drop in drum mode MIDI clip editor.
  * Quick hack to get latency compensation when recording.
  * Introducing count-in to audio and MIDI metronomes
  * Corrected MIDI metronome bar/beat note durations.
  * Give an early reponse upon opening any NSM session.
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.31:
  * Fixed a off-by-one rounding error on MIDI clip offset and lengths
  that were leaving some clips unlinked on load.
  * LXVST_PATH environment variable now accrues to VST_PATH for Linux-
  native VST2 plug-ins search path and not taking over in precedence
  anymore.
  * Fixed an old mistake on custom aliased CLAP and VST3 plugin paths.
  * Plugin latency/delay compensation now in effect immediately after
  changing track option (cf. Track/Properties... /Plugins/Latency
  compensation).
  * Shade-off regions not-in-view from the thumb-views.
  * Improved MIDI queue time drift correction resilience and stability
  against in-flight tempo changes.
  * The main real-time process cycle now runs on uniform block-sizes,
  in strides of 64 frames per period, meaning a higher resolution
  automation, independent of buffer-size.
  * The internal main MIDI engine gets its ALSA sequencer queue to a
  higher resolution (PPQN aka ticks-per-beat) and not subordinated
  to the current session's anymore.
  * Although being deprecated to use, JACK Session support is hopefuly
  fixed, once again.
  * Better discriminate CLAP Plug-in specific note events and strict
  MIDI dialect event processing.
* Sat Oct 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.9.29:
  * Capture same time(stamp) note-off tracking and postponing is
    now on trial, hopefully mitigating a legato issue, reported
    to MIDI wind instruments (EWI). (EXPERIMENTAL)
  * Fixed an old window parenting (aka z-level) issue, related to
    the Add Track and Track Properties dialogs and whether called
    from the main or mixer menus.
  * Fixed the out-of-process plugin scanner terminating too soon
    and sometimes miss some very last results.
  * Fixed another old bug in MIDI note-off messages not being sent
    while playing after a loop region.
  * Fixed a pretty ancient bug in the VST(2.x) plug-in program
    names inventory, present when building to the VeSTige header
    (which is still the default).
- Changes in 0.9.28:
  * Complete overhaul of the current host time(base)/BBT
    information delivered to plug-in types that matter: VST,
    VST3, CLAP and LV2.
  * Improved key-signature editing and display on Tempo
    Map / Markers (time-scale) management dialog.
  * Fixed plugin selection, when creating and switching initial
    track type, from audio to MIDI and vice-versa.
  * Fixed typos and updated some old MIDI GM2 Controller names.
  * Add current system user-name to the singleton/unique application
    instance identifier (when explicitly opted in at build configure
    time).
* Fri Jul  8 2022 Dave Plater <davejplater@gmail.com>
- Update to 0.9.27
- Upstream changes:
  * CLAP plug-in host support introduced. (EXPERIMENTAL)
  * Reviewed LV2 plug-in UI Touch feature/interface.
  * Auto-unlink MIDI clips when pasted/placed with Ctrl+click/Enter.
  * Fixed LV2 plug-ins UI X11 (native) initial size.
  * Fixed implicit deactivation when a plugin is removed from chain.
  * Fixed audio clip export, normalize and tempo-adjust when audio
  file number of channels is disparately greater than respective
  track's output bus count.
  * Fixed one killer lurking in MIDI Controller... modeless dialog
  instantiation.
  * Fixed non-effective automation curve node editing.
  * Track/Export Tracks... dialog ranges are not capped to current
  session-end anymore.
  * Fixed MIDI clip editor vertical-zooming when using the [Ctrl+]
  mouse-wheel.
  * Set auto-backward play-head location also when clicking on main
  track-view header/time-ruler and on thumb-view.
  * Fixed LV2 plug-in buffer-size initialization, esp. affecting the
  ZynReverb LV2 playback.
  * Export Tracks dialog last range selection is now remembered.
* Sat Jun 18 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.26:
  * Main application icon is now presented in scalable format (SVG).
  * Have even more tolerance to JACK buffer-size changes, prompting for a complete
    session reload, only when exceeding the double of the previous/current size.
  * Added an additional status-bar label to show the session current buffer-size
  * Migrated command line parsing to QCommandLineParser/Option (Qt >= 5.2)
    Make last recorded clip current and suitable target for immediate loop
    recording takes switch or navigation.
  * Number of takes is now shown on clip titles and tooltips.
  * Fixed in-flight transport mode changes.
  * Fixed translations path to be relative to application runtime.
  * Hopefully fixed an old MIDI off-timing bug noticeable only when exporting
    (Track/Export Tracks/Audio...) on large buffer-sizes (>= 2K frames/period).
  * Clip/File Loop Set menu command is now a toggle.
  * Fixed problem with punch-in/out and loop-recording being lost when stopping the
    play-head right after and between the loop-start and punch-in points, even
    though at least one cycle or take is through.
  * Dropped autotools (autoconf, automake, etc.) build system.
  * A more verbose warning question is issued, on whether to continue saving to an
    existing zip/archive directory and accept to replace and erase all its current
    data in the future.
  * Fixed potential crash on session close or application exit, when some plugins
    have been removed.
* Wed Feb 23 2022 Fabio Pesari <fpesari@tuxfamily.org>
- Removed "Requires: jack" as libjack.so.0 is already automatically
  required and it conflicts with pipewire-libjack
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.24:
  * A new option has been added to reset/resend all MIDI track/channel
    and buses controllers on playback start (cf. View/Options.../MIDI/
    Playback/Reset all controllers on playback start).
  * Whenever possible, avoid suggesting Save As... to an extracted
    archive/zip directory.
  * Fixed an old nasty mistake when renaming session names and then
    saving into an archive/zip bundle file (.qtz).
  * Fixed Mixer multi-row automatic layout consistency, when adding
    new or removing existing tracks or buses.
  * Dropped the 'Activate' option on the plug-in Selection dialog,
    now being as always on by default.
  * Have some tolerance for JACK buffer-size changes, only prompting
    to a complete session reload, if increasing in double the initial
    period size.
  * Introducing plug-in blacklisting, on user discretion (in View
    /Options.../Plugins/Blacklist) and on inventory scan (crashed
    plug-ins are now automatically blacklisted).
  * Added special support for LV2 UI GTK2 plugins based on Gtkmm 2.4
    framework.
  * All builds default to Qt6 (Qt >= 6.1) where available.
  * CMake is now the official build system.
- remove qtractor-powerpc.patch : upstream
* Sat Jul  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.9.22
  * Fixed a old bug that was preventing MIDI tracks volume and
    panning automation to take effect on audio export.
  * All packaging builds switching to CMake
* Sat May  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.9.21
  * Fixed and improved automation curve recording, whenever playback
    is rolling
  * Fixed parsing/loading of large session bundle archive/zip files
  * Fixed LV2 plug-in UI X11 (native) resize.
  * Make NSM state file names independent to session display names,
    keeping backward compatibility for old sessions.
  * Exiting, quitting or closing the main window while under NSM,
    now promptly asks whether to save, discard or cancel as usual.
  * Re-improved Mixer multi-row layout.
  * Fix incorrect destruction order for VST3 modules.
  * Ignore snap while ALT key is pressed, on the main track-view and
    the MIDI clip editors.
  * Fix IPlugView leaks for VST3 plugins.
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 0.9.19:
  - Session directory auto-name option added to the session properties
    dialog, as convenience.
  - Loading and saving a LV2 plugin's state has been vastly improved.
    IMPORTANT CAVEAT: From this moment onwards, when loading any newer
    saved sessions into older versions of the program, all LV2 plugins
    won't get their state restored correctly.
  - Track colors saturation introduced as yet another eye-candy option
    (cf. View/Options.../Display/Track color saturation)
  - Fixed VST3 number of channels query/report.
  - Fixed immediate crash when loading untitled or unnamed Instrument
    Definitions files (*.ins): base file-name is now taken as default
    instrument definition name or title.
  - Tempo (BPM) entry may now be specified with arbitrary precision, to
    at most 3 decimal positions in fractional part, while integer whole
    values are displayed with no decimal point.
  - Added option to keep MIDI clip editor windows (aka. piano-roll)
    always on top of the main window (cf. View/Options.../General/
    Keep editor windows always on top).
  - MIDI clip editor status-bar labels are not stretched to whole text
    size anymore, most specially for the current file complete path.
  - When under NSM, all top-level windows, main, mixer and connections,
    will always start hidden.
  - Plugin editors (GUIs) that are currently open on a track are now
    brought up as top-level windows immediately when a track is made
    current or highlighted (and Track / Auto Monitor is in effect).
  - MIDI clip editor mouse hovering effect extended to whole current
    note line on main view (piano-roll eye-candy++); also, the white
    keys on MIDI clip editor's virtual piano keyboard, are now fully
    highlighted.
  - Plugin search paths (cf. View/Options.../Plugins/Paths) now showing
    all the default and actual existing paths, instead of a blank list.
  - Undimmed octave divider lines on the piano-roll.
  - Fixed potential crash on changing audio output buses channel count.
  - Note names display (inside note rectangles) are now an option on
    the MIDI clip editor (aka. piano-roll; menu View > Note Names).
  - Early fixing to build for Qt >= 6.0.0 and the C++17 standard.
  - Fixed crash when changing an auto-monitored audio track's number
    of channels due on switching its audio output bus.
  - Avoid a complete track re-open when changing properties, unless
    either input or output buses are changed.
  - Fixed custom track icon selection when none is currently set.
  - Experimental / High resolution plugin automation (14-bit) options
    is now also removed from View > Options... > Plugins dialog.
  - Audio Clip / Export... now takes into account custom fixed gain
    property (shamefully missing for the whole last decade to date).
  - Finally indulged on dummy LV2 plug-in CVPort support, just to
    avoid certain immediate and sudden crashes when inserting those
    kind of 'non-functional' plugins accidentally.
  - Bring the Track Export dialog down to Clip Merge/Export as well,
    for optional file type and format selection.
  - When enabled, do auto-save upon adding or inserting a new plugin.
  - Make sure LV2 plug-in UI GTK2 and X11 native support is selected
    first by default on top to libsuil.
  - Both out-of-process plugin inventory scan and LV2 Dynamic manifest
    options have been removed from View > Options... > Plugins dialog.
  - Fixed deprecated stuff on an early preparation for Qt6.
  - Fixed MIDI tracks export that were missing the end-of-export tail
    parameter and bailing out always with default SMF format anyway.
  - Fixed VST3 component/controller inter-connection.
  - LV2 Atom/Port-event host notification support has been retouched,
    but still unofficial though.
  - Fixed VST3 audio-processor initialization/activation when a plugin
    has no inputs or outputs present.
  - Let main window pseudo-asynchronous stabilization re. menus, tools
    and status bars, just faster and immediate.
  - Fixed MIDI track monitor reinstantiation and reset.
* Wed Jun  3 2020 Dave Plater <davejplater@gmail.com>
- Update to version 0.9.14 and fix factory build.
- Upstream changes:
  * LV2 plug-in UI GTK2 and X11 in Qt5 host native support in addition
  and alternative to libsuil.
  * Generic plug-in/Properties... dialog now showing each
  parameter/property automation status on a skeuomorphic aka. fake and
  tiny LED ;)
  * LV2 Plug-in Patch parameter/properties automation and MIDI
  Controller assignment/learn are now a possibility.
  * LV2 Atom/Port-event host notification support has been implemented
  (unofficial).
  * Fix clean-up of any recording leftovers.
  * JACK Transport latency is now taken into account for recording
  latency compensation.
  * Attempt to force correct audio clip offsets due on recording latency
  compensation are not quantized to MIDI metronomic time-scale anymore.
  * LV2 Plug-in MIDNAM support introduced.
  * Use Shift or Ctrl keyboard modifiers with the mouse  *wheel to change
  any Direct Access plug-in parameters (issue #257).
  * All meters background color are now customize-able (cf.
  View/Options.../Display/Meters, color level "Back").
  * Automatic mixer grid layout (multi-row) is now in effect
  permanently--being an option no more.
  * Always show plugins and meters on track list/left pane as permanent
  standard now.
  * LV2 UI Request-value feature/interface support has been implemented.
  * Audio output monitoring meters are now shown/hidden auto-magically
  on MIDI tracks and/or buses--no need for some user preference option
  anymore (ie. View/ Options.../Plugins/Instruments/Show audio output
  monitoring meters, is now gone).
  * Default track height has been slightly increased.
  * Track / Duplicate Track... now also takes a MIDI track's audio
  meters setting into account.
  * Fixed first bar/measure position drawing on the time-scale/grid
  across time-signature changes on the MIDI clip editor (aka.
  piano-roll) (hopefully fixing issue #245).
  * Plugins and meters on track list/left pane, are now being set on as
  default--maybe going stapled in some near future ;)
  * Avoid resetting top or left position when zooming with mouse pointer
  is in main tracks or MIDI clip editor (piano-roll) views.
  * Basic key-signature has been added to tempo, time -signature and
  location markers map.
  * MIDI Clip editor (aka. piano-roll) horizontal and vertical splitter
  sizes, widths and heights resp. are now preserved as user preferences
  and also to session state.
* Sat Nov  2 2019 Dave Plater <davejplater@gmail.com>
- Update to version 0.9.10
- Upstream changes:
  * Fixed the potential crash-effect in switching MIDI
  output buses on tracks that are set to show audio
  output monitoring meters.
  * Fixed initial session tempo override when importing
  a standard MIDI file (as reported on issue #230).
  * An alternate time-signature/meter option is being
  served to the MIDI clip editor (aka. piano-roll)
  and allowing for some poly-rythm/meter scenarios
  on a per MIDI clip basis.
  * Fixed MIDI "overdub" recording on offset clips.
  * MIDI bank and program settings now propagating to
  all MIDI track's clips resp.
  * Fixed MIDI file format default setting other than
  SMF Format 0.
  * Escape key may now be used to reset time and tempo
  /time-sgnature spin-box controls.
  * Play-head time and tempo/time-signature controls
  are now featured in MIDI clip editor toolbars (aka.
  piano-roll); time display format is also separated
  from the tracks main application view and defaults
  to BBT as being most convenient.
  * All items in the MIDI clip editor's event list are
  now enabled, selectable and editable, no matter the
  filter settings for the event views.
  * Added alternate yet non-official CMake build option.
  * Improved MIDI clip editor (aka. piano-roll) position
  and size persistence across session state.
  * Fix HiDPI display screen effective support (Qt >= 5.6).
  * Mixer, Connections and MIDI clip editor top-level
  windows shall have no parent, unless when set as
  always-on-top tool windows. (REGRESSION)
  * Make sure compiler flags comply to c++11 as standard.
* Sat Sep 29 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.2
  * AppData/AppStream metadata is now settled under an all
    permisssive license (FSFAP); also updated to be the most
    compliant with latest freedesktop.org specification and
    recommendation.
  * Fix build for Qt >= 5.11.0 (by David Geiger, thanks);
    also for some g++ >= 8.1.1 warnings and quietness.
- Dropped qtractor-QAction.patch (no longer necessary)
* Mon Jun 11 2018 davejplater@gmail.com
- Update to release 0.9.1
- Fixes build against latest qt5 with qtractor-QAction.patch.
- Upstream changes:
  * Displaying MIDI note(on) events as diamonds instead
  of simple rectangles (aka. Drum Mode) is now being
  introduced as an optional MIDI track property (Drums)
  and as a MIDI clip editor (piano-roll) visual option
  (cf. View/Drum Mode).
  * Extended multi-selection is now supported on all the
  Connections client/port lists, allowing for multiple
  (dis)connections at once.
  * Added LV2 UI sample-rate option support.
  * Always reset all internal dedicated MIDI controllers,
  eg. MIDI track volume (CC#7) and panning (CC#10), on
  Transport/Panic and after rendering export to aud1io
  (ie. Track/Export Tracks/Audio...) as needed to reset
  MIDI instrument plugins to nominal session state.
  * Fix, detect and preserve MIDI Bank-select method across
  MIDI track/clips editing operations.
  * Fixed MIDI track and clip note min/max display range
  while recording and also when duplicating tracks.
  * Added "All files (*.*)" filter to every file requestor
  dialog, wherever missing.
  * The tiny zoom-magnifier icons have been revamped.
* Tue Dec  5 2017 aavindraa@gmail.com
- Update to 0.8.5
  * Audio clip gain and panning properties are now taken into
    consideration when hash-linking (aka. ref-counting) their
    backend buffers.
  * New out-of-process plug-in inventory scan and cache option,
    replacing the old (aka. dummy) VST plug-in scan option and
    extending its function to all other plug-in types: LADSPA,
    DSSI and also LV2 (cache only).
  * A File System browser and tree-view is finally integrated as a
    dockable-widget on the main application window (cf. main menu
    View / Window / File System).
  * Drag-and-dropping of session, audio and MIDI files over the
    main track-list (left pane) is now possible, allowing for yet
    another quick means to open a new session or add new tracks to
    the current session.
  * MIDI input/capture time-stamping has been fixed as much to
    avoid missing inbound events, when play-head is near the loop
    end point and the loop-start is set below the absolute first
    half-a-second (<0.5sec).
  * LV2 Time/Transport speed information is now set on rolling when
    in audio export aka freewheeling mode.
  * Added *.SF3 to soundfont instrument files filter, on the
    View Instruments... > Import... file dialog.
  * A brand new View/Options.../Display/Meters/Show meters on
    track list/left pane option has been added.
- use new official url
- binary removed: qtractor_vst_scan
- binary added:   qtractor_plugin_scan
* Fri Nov  3 2017 aavindraa@gmail.com
- Update to 0.8.4
  - Assigned MIDI Controllers to plug-in's Activate switch are now
    finally saved and (re)loaded properly across sessions.
  - Audio clip panning option property is now being introduced.
  - Out-of-process (aka. dummy) VST plug-in inventory scanning now
    restarts automatically and resumes processing in case of a
    premature exit/crash; VST plug-in inventory scan/cache
    persistency is now in place.
  - Desktop entry specification file is now finally independent
    from build/configure template chains.
  - Updated target path for freedesktop.org's AppStream metainfo
    file (formerly AppData).
  - Changing the View/Options.../Display/Custom/Style theme takes
    effect immediately unless it's back to "(default)".
  - Slightly slower but better approximation to IEEE 32bit
    floating point cubic root ie. cbrtf().
- remove qtractor-remove_path_from_exec_in_desktop_file.patch
  (fixed upstream)
- Lint spec file
- appdata xml is moved to the appropriate folder
* Fri Aug 25 2017 olaf@aepfle.de
- Enable mad and Qt5 unconditionally
* Sun Jul  2 2017 davejplater@gmail.com
- Update to version 0.8.3
- Upstream changes:
  * Make sure any just recorded clip filename is not reused
  while over the same track and session. (CRITICAL)
  * LV2 Plug-in worker/schedule interface ring-buffer sizes
  have been increased to 4KB.
  * Fixed track-name auto-incremental numbering suffix when
  modifying any other track property.
  * WSOLA vs. (lib)Rubberband time-stretching options are now
  individualized on a per audio clip basis.
  * Long overdue, some brand new and fundamental icons revamp.
  * Fixed a tempo-map node add/update/remove rescaling with
  regard to clip-lengths and automation/curve undo/redo.
  * Fixed a potential Activate automation/curve index clash,
  or aliasing, for any plug-ins that change upstream their
  parameter count or index order, on sessions saved with
  the old plug-in versions and vice-versa.
* Thu May 11 2017 ecsos@opensuse.org
- Update to 0.8.2
  - Track-name uniqueness is now being enforced, by adding an
    auto-incremental number suffix whenever necessary.
  - Attempt to raise an internal transient file-name registry to
    prevent automation/curve files to proliferate across several
    session load/save (re)cycles.
  - Track-height resizing now meets immediate visual feedback.
  - A brand new user preference global option is now available:
    View/Options.../Plugins/Editor/Select plug-in's editor (GUI)
    if more than one is available.
  - More gradient eye-candy on main track-view and piano-roll
    canvases, now showing left and right edge fake-shadows.
  - Fixed the time entry spin-boxes when changing time offset or
    length fields in BBT time format that goes across any
    tempo/time-signature change nodes.
  - French (fr) translation update (by Olivier Humbert, thanks).
* Mon Feb 20 2017 davejplater@gmail.com
- Update to 0.8.1
- Removed qtractor-nodatetime.patch, no trace of __DATE__ or
  __TIME__ anymore.
- Upstream changes:
- The View/Options.../Display/Dialogs/Use native dialogs
  option is now set initially off by default.
- All tempo and time-signature labels are now displayed
  with one decimal digit, as it was in mostly everywhere
  else but the time ruler/scale headers.
- JACK transport tempo and time-signature changes are now
  accepted, even though playback is not currently rolling;
  also, changing (JACK) Timebase master setting (cf.View/
  Options.../General/Transport/Timebase) will take effect
  immediately, not needing nor warning for session restart
  anymore.
- Track/Navigate/Next and Previous menu commands, finally
  fixed to wrap around the current track list.
- Current session (JACK) transport mode option switching is
  now being made accessible, from the main menu and drop-down
  toolbar buttons, as well as user configurable PC-keyboard
  and/or MIDI controller shortcuts (cf. Transport/Mode/None,
  Slave, Master, Full).
- Fixed some auto-backward play-head position flip-flopping,
  when opening a new session while the previous was still on
  rolling/playing state, hopefully.
- Added French man page (by Olivier Humbert, thanks).
- MIDI clip changes are now saved unconditionally whenever
  the editor (piano-roll) is closed or not currently visible.
- Audio clip peak/waveform files re-generation performance,
  scalability and resilience have been slightly improved.
- Some sanitary checks have been added to audio clip peak/
  waveform re-generation routine, as much to avoid empty,
  blank, zero or negative-width faulty renderings.
- Do not reset the Files tree-view widgets anymore, when
  leaving any drag-and-drop operation (annoyingly, all
  groups and sub-groups were being closed without appeal).
- Make builds reproducible byte for byte, by getting rid of
  the configure build date and time stamps.
- For more changes since 0.7.8 see:
  /usr/share/doc/packages/qtractor/ChangeLog
* Thu Aug  4 2016 olaf@aepfle.de
- Use buildconditional for mad support
* Fri Jun 24 2016 davejplater@gmail.com
- Update to release 0.7.8 and fix gcc6 build see boo#985243
- refresh qtractor-nodatetime.patch
- Upstream changes:
  * MIDI file track names (and any other SMF META events) are now
  converted to and from the base ASCII/Latin-1 encoding, as much to
  prevent invalid SMF whenever non-Latin-1 UTF-8 encoded MIDI track
  names are given.
  * MIDI file tempo-map and location markers import/export is now
  hopefully corrected, after almost a decade in mistake, regarding
  MIDI resolution conversion, when different than current
  session's setting (TPQN, ticks-per-quarter-note aka.
  ticks-per-beat, etc.)
  * Introducing LV2 UI Show interface support for other types than
  Qt, Gtk, X11 and lv2_external_ui.
  * Prevent any visual updates while exporting (freewheeling) audio
  tracks that have at least one plugin activate state automation
  enabled for playback (as much for not showing messages like
  "QObject::connect: Cannot queue arguments of type 'QVector'"
  ... anymore).
  * The common buses management dialog (View/Buses...) sees the
  superfluous Refresh button finally removed, while two new button
  commands take its place: (move) Up and Down.
  * LV2 plug-in Patch support has been added and LV2 plug-ins
  parameter properties manipulation is now accessible on the
  generic plug-in properties dialog.
  * Fixed a recently introduced bug, that rendered all but one
  plug-in instance to silence, affecting only DSSI plug-ins which
  implement DSSI_Descriptor::run_multiple_synths() eg.
  fluidsynth-dssi, hexter, etc.
* Thu Apr 28 2016 ecsos@opensuse.org
- update to 0.7.7
  - LV2 UI Touch feature/interface support added.
  - MIDI aware plug-ins are now void from multiple or parallel
    instantiation.
  - MIDI tracks and buses plug-in chains now honor the number of
    effective audio channels from the assigned audio output bus;
    dedicated audio output ports will keep default to the stereo
    two channels.
  - Plug-in rescan option has been added to plug-ins selection
    dialog (yet another suggestion by Frank Neumann, thanks).
  - Dropped the --enable-qt5 from configure as found redundant
    given that's the build default anyway
  - Immediate visual sync has been added to main and MIDI clip
    editor thumb-views
  - Fixed an old MIDI clip editor contents disappearing bug,
    which manifested when drawing free-hand
    (ie. Edit/Select Mode/Edit Draw is on) over and behind its
    start/beginning position (while in the lower view pane).
* Wed Apr  6 2016 ecsos@opensuse.org
- update to 0.7.6
  - Plug-ins search path and out-of-process (aka. dummy) VST
    plug-in inventory scanning has been heavily refactored.
  - Fixed and optimized all dummy processing for plugins with more
    audio inputs and/or outputs than channels on a track or bus
    where it's inserted.
  - Fixed relative/absolute path mapping when saving/loading
    custom LV2 Plug-in State Presets.
* Tue Mar 22 2016 ecsos@opensuse.org
- update to 0.7.5
  - Beat unit divisor, aka. the denominator or lower numeral in the
    time-signature, have now a visible and practical effect over
    the time-line, even though the standard MIDI tempo(BPM) is
    always denoted in beats as quarter-notes (1/4, crotchet,
    seminima) per minute.
  - Fixed an old hack on LV2 State Files abstract/relative
    file-path mapping when saving custom LV2 Presets (after a
    related issue on Fabla2, by Harry Van Haaren, thanks).
  - Default PC-Keyboard shortcuts may now be erasable and re-
    assigned (cf. Help/Shortcuts...).
  - New option on the audio/MIDI export dialog, on whether to
    add/import the exported result as brand new track(s).
  - Introducing brand new track icons property.
  - Old Dry/Wet Insert and Aux-send pseudo-plugin parameters are
    now split into separate Dry and Wet controls, what else could
    it possibly be? :)
  - Brand new MIDI Insert and Aux-Send pseudo-plugins are now
    implemented with very similar semantics as the respective and
    existing audio counterparts.
  - Implement LV2_STATE__loadDefaultState feature (after pull
    request by Hanspeter Portner aka. ventosus, thanks).
  - Plug-ins search paths internal logic has been refactored; an
    alternative file-name based search is now in effect for LADSPA,
    DSSI and VST plug-ins, whenever not found on their original
    file-path locations saved in a previous session.
  - Finally added this brand new menu Clip/Cross Fade command,
    aimed on setting fade-in/out ranges properly, just as far to
    (auto)cross-fade consecutive overlapping clips.
* Sat Jan 30 2016 ecsos@opensuse.org
- update to 0.7.4
  - Eye-candy warning: muted/non-soloed tracks are now shaded over
    the main thumb-view.
  - Faster and crispier VST plugin editor (GUI) idle cycles.
  - Fixed all core processing when any plugin has more audio
    outputs than channels on a track/bus where it's inserted.
  - Added one decimal digit to all percentage input spin-boxes on
    the MIDI Tools dialog.
  - Added brand new and global option to disable the so called
    "catch-up" default behavior (cf. View/Controllers.../Sync).
  - Fixed some track control issues related to MIDI Controllers
    generic mapping (cf. View/Controllers...).
  - Try making Help/Shortcuts... dialog window modeless, as far as
    under MIDI Controller, Inputs/Outputs Connections window also
    gets accessible enough.
  - Fixed some vertical scrolling and play-head line re-drawing
    glitches introduced by the recent unlimited slack to editing
    beyond current contents length on main tracks view.
  - Added one decimal digit to the Pitch-shift spin-box on audio
    Clip/Edit... properties dialog window.
  - Added application keywords to freedesktop.org's AppData.
  - Fixed local keyboard shortcuts on the Files organizer widget
    actions and context-menu.
  - Improved Mixer multi-row layout (patch by Holger Marzen aka.
    bluebell, thanks).
  - Fixed the Ctrl+drag/cloning left of a clip when towards near
    the beginning of session.
* Wed Dec 30 2015 ecsos@opensuse.org
- update to 0.7.3
  - Slight increase on the number of decimal digits for the plugin
    parameters while on the generic plugin properties dialog. Also
    applied to automation curve node value editing.
  - Unlimited slack is now in effect on editing over and beyond
    the current session or clip contents length, on both the main
    tracks and MIDI clip editor (piano-roll) views.
  - Ctrl+click and dragging the left or right edges of a clip will
    now make it spill over and replicate as many clip clones as it
    fits in the left or right horizontal extent.
  - Added View/Note Type and Value Type command menus to the MIDI
    clip editor (aka. piano-roll) which opens the possibility for
    discrete shortcuts to switching views eg. Note Velocity and
    Controller views (after a kind request by yubatake, thanks).
  - Fixed the conversion and/or override of MIDI clip offsets when
    moving and copy/pasting across tempo/time-signature changes.
  - Fixed MIDI file track/channel duration estimator, which was
    giving quite wrong and way too short reads.
  - Fixed a drag-and-drop bug over the main tracks view, when new
    tracks were being inserted at the top and not to the bottom as
  is normally indicated by the floating visual placeholder.
  - Fixed LV2UI_Resize handle from extension_data(LV2_UI__resize),
    now passing LV2UI_Handle in first argument to ui_resize(), as
    found correct and needed for resizable/scaleable LV2 UI's, most
    specially to ssj71's so called Infamous Plugins, thanks.
* Sun Dec 13 2015 davejplater@gmail.com
- Refreshed patches and add conditional buildrequires.
* Fri Dec 11 2015 ecsos@opensuse.org
- update to 0.7.2
  - Yet another audio/MIDI time drift correction fix, now giving it
    some slack while turnaround looping on tempo changes.
  - Prevent x11extras module from use on non-X11/Unix platforms.
  - MIDI Track/Instrument cascading pop-up menus have been added,
    to main and MIDI clip editor windows.
  - VST Plugin preset/bank files support (FXB/FXP) is now being
    integrated to the generic Plugin/Properties widget dialog.
  - Added new Track/Duplicate menu command.
  - Added simple XRUN red indicator to status bar.
  - Make sure program change/presets are not selected on possibly
    multi-timbral instrument plugins when inserted on a MIDI bus.
  - Prefer Qt5 over Qt4 by default with configure script.
  - Fixed a potential crash-bug on first enabling either once the
    audio or MIDI metronomes.
- remove non-atomic-arches.patch because changes now in source
* Sun Oct 11 2015 ecsos@opensuse.org
- update to 0.7.1
  - Fixed an ages old MIDI track/channel instrument mapping (bank,
    program) issue that prevented normal all-shut-up messages from
    being sent to MIDI output buses/ports on playback stop.
  - Messages standard output capture has been improved again, now
    in both ways a non-blocking pipe may get.
  - Fixed port on MIDI 14-bit controllers input caching.
  - Fixed false value readings on the MIDI clip editor (aka. piano
  - roll) tool-tips, when dragging a note velocity or controller
    value outside the acceptable nominal range (eg. 0-127).
  - Added LV2_BUF_SIZE__nominalBlockLength option support (patch
    by falktx aka. Filipe Coelho, thanks).
  - Fixed wrong initial tempo/time-signature display when session
    is loaded from command line.
  - LV2 plug-in UI GTK2 and X11 in Qt5 host native support added.
  - Transport/Auto Backward feature now honoring (auto return) to
    same current location precedence as Transport/Backward.
  - Single/unique application instance control adapted to Qt5/X11
    (cf. configure --enable-xunique).
  - MIDI Tools/Transpose, Resize duration display format (frames,
    time or BBT) have been fixed.
  - Build fix for Qt5.5 (patch by KaOS, thanks).
  - MIDI Tools/Quantize et al. are tentatively being corrected
    to take event times as relative to THE beginning of session,
    instead of MIDI clip start location.
- update to 0.7.0
  - Complete rewrite of Qt4 vs. Qt5 configure builds.
  - Revised MIDI Controlllers catch-up algorithm.
  - Mixer multi-row layout gets a little bit of a fairness fix.
  - Non-continuous MIDI Controllers now have their Hook and Latch
    options disabled as those are found not applicable,
  - As an alternative to PC-keyboard shortcuts, MIDI controllers
    are now also assignable and configurable for any of the main
    menu command actions, all from the same old configuration
    dialog (Help/Shortcuts...).
  - Fixed missing Track and Clip sub-menus from Edit/context-menu
    that were found AWOL ever since after the Lazy Tachyon beta
    release (> 0.6.6).
  - An off-by-one bar position (as in BBT, bar, beat and ticks)
    has been purportedly fixed as long as LV2 Time/Position atom
    event transfer goes.
  - French (fr) translation line to desktop file added (patch by
    Olivier Humbert, thanks).
  - A new top-level widget window geometry state save and restore
    sub-routine is now in effect.
  - Improved MIDI clip editor resilience across tempo and time-
    signature changes.
  - Keyboard shortcuts configuration (Help/Shortcuts...) now
    lists complete menu/action path where available.
  - Fixed in-flight VST plugin editor (GUI) resizing.
  - Added support to LV2UI_portMap extension, found really handy
    for the cases where you have multiple plugins with different
    port configurations and a single common UI to drive them all
    (pull request by Hanspeter Portner aka. ventosus, thanks).
* Thu May 28 2015 ecsos@opensuse.org
- update to 0.6.7
  * MIDI clip editor (aka. piano-roll) position, size, and view
    /event type criteria are now persistent, across session and
    user preferences application state.
  * Generic plugin form widget position is now also preserved
    across open/save session cycles.
  * MIDI clip editor resilience is about to get an improvement,
    fe. it doesn't close on stopping record/overdub anymore.
  * Introducing (JACK) Timebase master setting as an option to
    Transport mode (cf. View/Options.../General/Transport
    /Timebase).
  * LV2 plug-in MIDI/Event support now slanted for deprecation.
  * Spanish (es) translation added, by avid Reyes Pucheta.
  * It's live: audio track export (cf. Track/Export Tracks/ Audio.)
    has been deeply refactored to finally include MIDI t
    rack/instrument plugins rendering (aka. freeze) on selected
    audio output buses on mix-down. (EXPERIMENTAL)
  * MIDI file player now does (N)RPN 14-bit controller events.
  * Track properties dialog output bus switch fix/optimization;
    also fixed multiple DSSI instance reference count on close.
  * Fixed for some strict tests for Qt4 vs. Qt5 configure builds.
  * German (de) translation update (by Guido Scholz, thanks).
* Sat Apr  4 2015 dmueller@suse.com
-   add non-atomic-arches.patch: build for arches other than x86
* Sat Apr  4 2015 benoit.monin@gmx.fr
- update to 0.6.6:
  * MIDI clip record/reopen to/from SMF format 0 has been fixed.
  * LV2 and VST plugins GUI editor widget position is preserved
    across hide/show cycles.
  * Added application description as freedesktop.org's AppData.
  * Added a "Don't ask this again" prompt option to zip/archive
    extrated directory removal/replace warning messages.
  * MIDI clip editor (aka. piano-roll) gets lingering notes
    properly shown while on record/overdubbing.
  * Current highlighted client/port connections are now drawn
    with thicker connector lines.
  * Fixing segfaults due to QClipboard::mimeData() returning an
    invalid null pointer while on Qt5 and Weston.
  * Return of an old hack/fix for some native VST plugins with
    GUI editor, on whether to skip the explicit shared library
    unloading on close and thus avoid some mysterious crashes
    on session and/or application exit.
  * Force reset of plugin selection list when any of the plugin
    search paths change (in View/Options.../Plugins/Paths).
  * Recursive VST plugin search is now in effect for inventory
    and discovery on path sub-directories (VST only).
  * Non-dummy scannig for regular VST, non-shell plugins, were
    doomed to infinite-loop freezes on discovery, now fixed.
- changes from 0.6.5:
  * Connections lines now drawn with anti-aliasing; connections
    splitter handles width is now reduced; the MIDI connections
    splitter pane sizes are now saved and restored properly.
  * Extended multi-selection is now featured on the track-list
    (main left-pane), primarily allowing for group mute/solo
    (and monitor) switching.
  * Track-list (left pane) header column widths are now saved
    and made persistent across application power cycle (double
  - click reverts to the old original default).
  * Minor fixes on the MIDI clip event list editor, also making
    sure the current event is visible on the piano-roll view.
  * As long to prevent asynchronous mistakes to JACK transport
    state changes, an internal slack-delay is now introduced
    after self-initiated transport commands (eg. start/stop).
  * The MIDI clip editor (aka. piano-roll) was missing to
    clear or reset the current selection when no shift/ctrl
    keyboard modifier is in effect.
  * VST-shell sub-plugins are now supported (as suggested by
    abique aka. Alexandre Bique, thanks).
  * MIDI clip record/overdubbing is now possible (Clip/Record
    on the main menu or File/Record from the MIDI clip editor.
  * Make sure some audio sample file encodings (eg. old Ogg
    Vorbis) does not head-start on audio peak generation.
- changes from 0.6.4:
  * Fixed some old loop-recording clip drawing glitches.
  * Current assigned track/channel instrument definition
    names for MIDI controllers, note keys, RPN and NRPN,
    are now in effect on the MIDI clip editor drop-down
    lists, whether available.
  * Clip/Take/Range... input dialog values are now properly
    sanitized as long to prevent invalid take/folding ranges.
  * Audio capture/export file type default now set to "wav".
  * Extending punch-in/out over loop-recording/takes modes.
  * Make audio tracks monitoring always flow while playback
    is rolling, independently of their mute/solo state.
  * Fixed undo/redo conversion of audio clip offsets under
    (automatic) time-stretching eg. due on tempo changes.
    (ticket by Holger Marzen, thanks).
  * Latch/momentary MIDI Controllers toggle mode introduced
    (a request by AutoStatic aka. Jeremy Jongepier, thanks).
  * JACK client/port pretty-name (metadata) support is being
    seamlessly introduced. (EXPERIMENTAL)
  * Audio frame/MIDI time drift correction is now an option on
    View/Options.../MIDI/Playback/Enable MIDI queue time drift
    correction.
  * Transport auto-backward feature now honoring last position
    playback was started.
  * Introducing brand new application user preferences on
    View/Options.../Display/Options/Custom style and color
    themes (eg. "KXStudio", by Filipe Coelho aka. falkTX).
  * Mixer widget gets automatic multi-row strip layout.
  * Clip fade-in/out now follows time-stretch resizing, via
    shift/ctrl+click and drag one of its edges.
  * Fixed a typo causing FTBFS when VST plug-in support is
    explicity disabled (./configure --disable-vst).
- refresh qtractor-nodatetime.patch: line numbers changed
- add qtractor.appdata.xml to the package
* Fri Sep 26 2014 ecsos@schirra.net
- update to 0.6.3
  * Make the mouse-wheel to scroll the plugin list views, when
    not hovering a direct-access parameter slider.
  * Mixer widget gets (un)dockable Inputs and Outputs panels,
    also with their respective title captions.
  * Plugin instantiation is now constrained as much to prevent
    any audio channel output overriding.
  * Existing plugin presets may now be selected right(-click)
    from plugin list context-menu (ticket by Harry van Haaren,
    thanks).
  * So-called "painting" over multiple selected event values,
    while on the MIDI clip editor view pane below the main
    piano-roll (eg. note velocities, controller values, etc.)
    is now split into two similar painting modes, whether the
    sub-menu Edit/Select Mode/Edit Draw is set on (free-hand)
    or off (linear).
  * Drag-and-copy of plug-in instances across tracks or buses
    (ie. cloning) now also copies the direct access parameter
    setting (ticket by Holger Marzen, thanks).
  * File/Save As... now prompts and suggests an incremental
    backup name for existing sessions files.
  * Zooming in/out increment is now augmented by whether shift
    /ctrl keyboard modifiers are set (on a ticket request by
    Holger Marzen, thanks).
  * LV2 Time position event messages for plugin atom ports that
    support it is now being implemented.
  * Attempt to break extremely long audio file peak generation
    on session close or program exit (as reported by EternalX,
    thanks again).
  * MIDI Controllers Hook and Invert properties are now properly
    saved for tracks (after bug report by Nicola Pandini, thanks).
  * A segmentation fault when closing with VST plugins open has
    been hopefully fixed (after a patch by EternalX, thanks).
  * Messages standard output capture has been slightly improved
    as for non-blocking i/o, whenever available.
  * Automation curve node editing has been slightly improved
    in regard to time positioning and resolution.
- changes from 0.6.2
  * Prevent linear and spline automation curve modes for all
    integer valued subjects. Also, make sure those values are
    rounded to the nearest integer away from zero.
  * Fixed save of LV2 Presets for plugins with state files.
  * A man page has beed added (making up Gürkan Sengün's work
    on debian, thanks).
  * When moving plugins by eg. drag-and-dropping across tracks,
    automation curves were being left behind, maybe leading to
    unpredictable mistaken behavior. Hopefully, not anymore.
  * Translations install directory change.
  * Automation curves are now automatically re-adjusted to tempo
    map node changes (after a ticket by Holger Marzen, thanks).
  * Audio/MIDI files or plugins found missing on session load
    are now subject for an explicit modal warning message and
    prompt for an immediate session backup salvage.
  * Changing instrument plugin programs is now an undo/redo-able
    command operation, especially for DSSI but also for plugins
    that come with the LV2 Programs interface extension support
    (http://kxstudio.sourceforge.net/ns/lv2ext/programs).
  * Drawing, selecting and/or resizing of MIDI note events that
    extend across tempo/time-signature changes is now made a bit
    more correctly over the MIDI clip editor (aka. piano-roll),
    especially regarding to current snap-to-beat setting (after
    an outstanding ticket by yubatake, thanks).
  * Once again, audio frame/MIDI time drift correction has been
    slightly refactored to improve MIDI input monitor and timing.
  * Discrete automation curve node values may now be edited via
    a numerical entry floating spin-box on double-click (as yet
    another request by AutoStatic aka. Jeremy Jongepier, thanks).
  * Pressing shift/ctrl keyboard modifiers while double-clicking
    on a plugin list entry now briefly reverses the current View
    /Options.../Plugins/Editor/Open plugin's editor (GUI) by
    default option preference.
  * Fixed an old crash lurker when switching output buses that
    implied a change on the number of audio channels, while on
    tracks that have (auto-)monitor turned on and at least one
    active plugin in chain (yet another ticket by AutoStatic
    aka. Jeremy Jongepier, thanks).
  * MIDI Controller assignment (aka MIDI learn) and/or automation
    of plugins (de)activation state has been added (as requested
    by AutoStatic aka. Jeremy Jongepier, thanks).
  * LV2 UI Idle and Show interfaces support added.
  * Allow the build system to include an user specified LDFLAGS
    (patch by Alessio Treglia aka. quadrispro, thanks).
- changes from 0.6.1
  * New user preference option added as View/Options.../Display
    /Transport/Hold auto-scrolling (follow play-head) on edits
    (after requests by Holger Marzen and Louigi Verona, thanks).
  * All color chooser dialogs were missing proper titles.
  * Audio peak file re-generation and clean-up has been hopefully
    fixed and cache optimized (re. drawing audio clip waveforms).
  * Fixed initial session snap-per-beat setting on main toolbar.
  * Clip/Export...'ed files are now made persistent, no questions
    asked (after a ticket by Oliver Kester, thanks).
  * Portuguese (pt) translation added (by Esteban Viveros, thanks).
- changes from 0.6.0
  * New user option added: on whether to save plugins automation
    values with higher resolution as possible, using 14-bit NRPN:
    cf. View/Options.../Plugins/Experimental/High resolution
    plugin automation (default=off).
  * Generic native plugin dialogs now shows an additional "About"
    last page where authorship credits are due.
  * A new user preference option is now in place for whether to
    use desktop environment's own native file requester/browser
    dialogs (View/Options.../Display/Dialogs/Use native dialogs).
  * A bit of slack have been introduced to put "Follow Playhead"
    (aka. auto-scroll view mode) on hold, while doing in-flight
    selection edit moves.
  * Fixed some user interface related annoyances while on the MIDI
    Controllers mappings (ie. View/Controllers...).
  * Fixed port origin on MIDI RPN/NRPN 14-bit controllers input.
  * A discretionary plug-in unique identifier have been devised for
    when more than one from the same type are inserted on a bus or
    track chain, avoiding destructive clashing of automation data.
  * Horizontal scrolling shift+mouse-wheel direction now reversed.
  * LV2 Dyn(amic)-manifest support is now optional (default=off);
    cf. View/Options.../Plugins/Experimental/LV2 Dynamic Manifest
    support).
  * The following options, although decieved on View/Options... as
    global configuration options, were always and still are proper
    session instance properties: (JACK) Transport mode, MMC mode,
    MMC device, MIDI SPP and MIDI Clock modes, are now shown there
    reflecting the current open session state.
  * A couple of run-time circumventions have been hacked in, both
    strictly related to when NSM session management is in charge:
    1) the new session template feature is disabled (was aborting
    initial NSM new client additions); 2) the native (as from the
    desktop environment eg. KDE) file browser/requester dialogs are
    disabled (were taking too long to list the current directory on
    first time invocation).
  * Update current automation/curve nodes selection while changing
    horizontal (time axis) zoom levels.
  * One liner's attempt to make it consistent behaviour on resizing
    and moving multiple selected notes or events while on the MIDI
    clip editor (aka. piano-roll; after a ticket request from Daniel
    MacDonald aka. danboid, thanks).
  * Introducing tiny quarter-note/crotchet/seminima/beat icon on all
    snap-to-beat selection items get a new icon :).
  * Corrected some audio buffering boundary conditions that were
    causing dead-loops/freezes while merging some audio clips.
  * Session auto-save period was chronically reduced to one third
    of its user setting; non critical but fixed now.
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- package changes:
  * removed patch, merged upstream: qtractor-0.5.10-cflags.patch
  * added patch: qtractor-remove_path_from_exec_in_desktop_file.patch
    (fixes warning in build because the .desktop file uses the fully-qualified
    path to /usr/bin/qtractor)
- update to 0.5.12:
  * fixed another off-by-one MIDI plugin chain timing bug, delaying the actual
    playback of the first MIDI event, whenever it started at the same and as
    long as the initial play-head position
  * a new LV2 host convention is in effect on plugins that expose multiple
    AtomPort's in either direction: only the first input or output declared
    AtomPort is eligible to convey regular MIDI data events
  * zooming with shift/ctrl+mouse-wheel and pointing over the main tracks view
    or MIDI clip editor time ruler header's now fixed
  * a rare freezing loop condition has been fixed on the oldest of MIDI file
    save/write routines
  * copy/paste now preserving clip names
  * scaling of whole tempo map with a given factor has been added, through a
    spin-box and button in Tempo Map / Markers dialog
  * when issued from main tracks view (ie. Clip/Tools menu) MIDI clip tools are
    now a bit more crash-resilient re. undo/redo- ability
  * session auto-save / crash-recovery support is now on trial as in
    View/Options.../General/Session/Auto-save current working session every 10
    minutes (default on)
  * plugin-list chain context-menu now includes MIDI instrument audio output
    options to existing non-dedicated output buses, any other than the previous
    hard-wired default (eg. Master)
  * tracks export now allows for the mix-down/merge of multiple audio/MIDI
    output buses (Track/Export Tracks)
  * when adding new tracks, try preserving the last selected bus names, while
    not the default Master ones
  * brand new thumb-(over)view toolbar widget added to MIDI clip editor window
    (aka. piano-roll overview)
  * general MIDI RPN/NRPN 14-bit controller support is now being introduced on
    real-time MIDI input parsing, on standard MIDI file I/O, on MIDI Controller
    options and, of course, on MIDI clip and event list editor
- changes from 0.5.11
  * adding a track now inserts it after the current one, if any; one can also
    drag and move a track below the last one in the track list (main view left
    pane)
  * extended Edit/Select Mode/Automation: multi-selection mode, cut, copy,
    paste and delete of current track's automation curve nodes, now reached
    implementation ready status
  * another old silent bug bites the dust: changing track names were dropping
    any track gain/volume and panning automation curves when saving the session
  * a primeval processing bug has been sorted out: aux-sends to audio output
    buses that just appear to be after the input bus where they're inserted
    were being left muted and silent
  * fixed a sure crash bug exposed when processing of aux-send plugins when
    inserted too early on audio input buses chain
  * Shift/Ctrl keyboard modifiers now set to extend current clip selection
    while in main track view's Edit/Select Mode/Range, Rectangle modes
  * main Edit/Select Mode/Automation icon retouched to look a bit more obvious
    and intuitive, hopefully
  * allow to change the velocities/values of the current selected events which
    have the exact same onset times and hide beyhond each other on the MIDI
    clip editor's pane below the main view piano-roll (ie. the one that
    represents MIDI event values as a bar chart)
  * fixed some problematic playback/export muting and annoying cleanup
    freezing, due on audio tracks with too many clips eg. more than hundred
    clip splits
  * LV2 UI resize feature support/control added
  * fixed dedicated MIDI control and MIDI metronome port connection restore
    conflict
  * new user preference option added: reverse middle-button role to Shift/Ctrl
    keyboard state, in special regard to edit-head/tail vs. play-head
    positioning while on the main track and MIDI clip editor (aka. piano-roll)
    views
* Fri Sep 13 2013 dvaleev@suse.com
- Fix build on powerpc (qtractor-powerpc.patch)
* Sat Sep  7 2013 reddwarf@opensuse.org
- Add qtractor-0.5.10-cflags.patch: Use RPM_OPT_FLAGS.
- Remove qtractor--fix_desktop_file.patch: No longer needed patch
- Add LV2 support (BuildRequires: pkgconfig(lilv-0))
- Add --disable-sse configure option.
- Add %%icon_theme_cache, %%mime_database and %%desktop_database scriplets
- Add SVG icons to file list
- Run %%make_install with STRIP=:
* Sat Aug 24 2013 prusnak@opensuse.org
- update to 0.5.10: see ChangeLog
* Fri Dec 28 2012 pascal.bleser@opensuse.org
- update to 0.5.7: see ChangeLog
* Wed Mar  7 2012 prusnak@opensuse.org
- updated to 0.5.4
  * Direct access plugin/insert parameter changing tool-tip added.
  * A Transport/Panic action enters the scene, in a nostalgic attempt
    to emulate the all-MIDI-track-shut-off command of those drop-dead
    and primordial MIDI sequencers of all time. Now finally a keyboard
    shortcut and mouse click-away ;)
  * MIDI editor command redo/undo adjustment now effective on all other
    channel events besides notes, which overlap at the same event time.
  * A new File/Unlink menu action is now made available from the MIDI
    clip editor (aka. piano-roll) for detaching the current linked/ref-
    counted MIDI clip into a new auto-incremented SMF filename.
  * Some audio/MIDI content/media-file resource management is entering
    the scene, taking care of some file-system house-keeping, this gets
    evident on unsaved/dead recorded files being automaticaly removed
    from the file-system, on session close.
  * Killed the old and entirely deprecated LV2 Save/Restore and Persist
    feature/extensions support.
  * Auto-monitored MIDI events are now merged/queued correctly into
    the instrument plugin playback queue, avoiding sudden crashes, hopefully.
  * Awesome patch from Albert Graef, thanks, which makes most MIDI SysEx
    to get through MIDI instrument plugins at last; applies to DSSI and
    LV2 plugins only.
  * LV2 URID map/unmap feature support added.
  * Plugin parameter value redo/undo command aliasing fix.
  * Double-clicking in plugin list item now show/activates the plugin's
    editor window (was toggling visibility/activation).
  * Plugin path settings have been fixed again, with special regards to an
    effective LV2_PATH environment variable settlement.
  * Session properties dialog now asks to create a new session directory
    if the given one does not currently exist.
  * MIDI note names and their respective octave numbers are now compliant
    with the ISO standard where middle C (60) is now C4 (was C3).
  * Fixed audible glitch/pop at the beginning of an audio clip with long
    quadratic or cubic shaped fade-in (reported by Lougi Verona, thanks).
  * MIDI Controller Auto-Hook patch by Alessandro Preziosi, thanks.
  * Make sure all MIDI note-off are always queued after their respective
    note-on events when buffering for MIDI input of instrument plugins,
    event though for zero duration MIDI note events (hopefully fixing
    the hanging notes bug #3476124, as reported by Albert Graef, thanks).
  * LV2 MIDI-fx plugin support has been repaired.
  * Single-track clip selection logic corrected again, fixing multi-clip
    selection drag/move across an odd number of distinct tracks (after
    a bug report by Louigi Verona, on linux-audio-dev, thanks).
  * MMC Locate time-code hour bit-field fix; MMC Locate now also on loop
    turnarounds (patches by Albert Graef, thanks).
  * Looping across multiple linked/ref-counted audio clips was incredibly
    broken with complete out-of-sync playback. Hopefully fixed now, with
    auto-unlinking/cloning all the affected audio clip buffers.
  * Audio clip overlapping detection off-by-one(-frame) fix.
  * MIDI Tools/Resize value ramp mode has been added (mocking the 'resize
    to range' feature request #3467894, by Daniel MacDonald aka. danboid).
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to 0.5.3
  * Fixed initial LV2 plugin UI widget/window titles.
  * Attempt to get any brand new LV2 plugins Qt4 enabled UI's
    working on either slv2 and lilv build modes ;)
    (nailed by falkTX, thanks).
  * Current clip is ultimately inferred from the one under
    the play-head position and current selected track;
    the last one clicked over and/or selected still has precedence
    (following request by Loiugi Verona).
  * Drag-moving clips horizontally with the keyboard arrow-keys
    just got a step better with a fixed minimum of one pixel,
    depending still on the current snap-per-beat setting and
    horizontal zoom level (as suggested by Louigi Verona, thanks).
  * Get maximum and minimum peak values back when drawing audio waveforms.
  * Automation play/feedback has been missed to show on those
    plugins that provide their own GUI, now on par with all the rest
    'homebrew' widgets (eg. generic plugin properties dialog).
  * All plugin parameters automation and selection were left
    inaccessible until the generic native plugin dialog is eventually
    shown, now fixed (re. bug #3463916).
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to 0.5.2
  * Fixed a probably old lurking destructive bug, which was incidental
    to when an invalid or non audio file is imported, intentionally
    or by mistake, into new or existing audio clips (eg. importing
    a MIDI file where an audio file is expected).
  * Force audio file closing to occur on the very same disk-write (sync)
    thread, possibly mitigating an old random crash issue lurking
    in the vorbis reference encoder (recording) re. the non thread-safeness
    of the vorbis_analysis() final call.
  * Fixed extraordinary shadow-playback of audio clips which extent
    were longer than the respective audio file length.
  * Default session file format option now promoted
    (see View/Options.../General/Session) in the way of whether
    file suffix gets honored upon session open or save (.qtr, .qts or .qtz).
    This brand new option also applies for default state file format
    on a JACK-session salvage context.
  * The View/Options... (aka. user preferences) dialog sees a new
    arranjement in layout, with some options moving into this
    brand new tab page called General.
  * LV2 State extension support has been added, which shall replace old LV2
    Persist extension interface in the near future. It also replaces
    the LV2 Files extension from now on (thanks to Dave Robillard).
  * Dirty MIDI clips are now auto-saved when MIDI track properties
    get changed through its own dialog.
  * Fixed one probable too old crash when canceling a new/add track dialog.
  * MIDI SysEx event list editing is now fixed.
  * Once again, make sure all recorded clips start and end at the very
    same position when multiple track recording is turned on/off,
    while playback is still rolling.
  * Fixed Makefile.in handling installation directories to the configure
    script eg. --datadir, --localedir.
  * Possible attempt to improve in-flight recording clip display,
    especially when looping and MIDI clips are involved.
  * MIDI clip revision (re)numbering paranoia has been improved as much
    to avoid MIDI file clashes as much as possible while editing multiple
    MIDI clips which reference the same SMF and track/channel.
  * Creating new or updating existing buses with exact same names of any
    current dedicated inputs/outputs (which are implemented as special
    covert buses) is now disallowed (preventing bug #3430406).
  * Loop-recording/takes functionality is now ready for the masses and
    accessible from brand new Clip/Take menu (Select, First, Previous,
    Next, Last, Reset and Range...; the latter is actually being provided
    as bonus feature :) as to fold any given clip into so-called takes,
    simulating loop-recording mode over an arbitrary range).
  * Loop-recording/takes infrastructure integration is sneaking in:
    all clips recorded under a loop/cycle range may now get split (folded)
    into one or more so-called takes. A new option is now provided,
    as to select which take is about to retain after the recording ends,
    either the First or the Last one. Just turn this mode off (None)
    and keep with the old recording behavior, where clips are laid out
    unfolded through the timeline, as usual
    (see menu View/Options.../Display/Loop recording mode).
  * Improved robustness in face of disabled audio buses when global maximum
    number of JACK (audio) ports is surpassed (mitigating bug #3421911).
  * Improved single-track clip selection status logic, (possibly fixing
    bug #3419141).
  * Clip/Unlink action is now available for detaching linked/ref-counted
    MIDI clips, renaming and saving into auto-incremental SMF filenames.
  * Temporary session archive directory now (pre)fixed with program name
    (eg. /tmp/qtractor).
  * Fixed VST GUI editor window title on first show.
  * Fixed build for ancient VST-SDK 2.3 (32bit only).
* Wed Oct 12 2011 mseben@gmail.com
- update to 0.5.1
  - More LADISH support: SIGTERM signal is now trapped for graceful
    application close.
  - Improved paste-repeat snap precision when dealing with large
    repeat counts.
  - Czech (cs) translation added, by Pavel Fric.
  - Added a few snap-to-beat divisors (unusual Beat/5, Beat/7,
    Beat/9 and Beat/10) for completeness sake.
  - Such a simple change of mind with a visual twist: the "A" track
    automation button/menu has now been
  - moved to the right-most, as it belongs ;)
  - Auto-connection of dedicated audio outputs is now optional
    for default audio master bus, metronome, player and MIDI
    instrument plugin dedicated audio outputs.
  - Finally, after a pitiful large brain-dead period, generic plugin
    forms are now showing all possible controllable plugin
    parameters featuring a paged, tabbed dialog, whenever applicable.
  - Special hack/fix for JUCE based native VST plugins, which are
    the most actually found with a GUI editor, skipping explicit
    shared library unloading and thus avoiding some mysterious
    crashes on session close and/or application exit.
  - Support for MIDI-fx plugins (native VST and/or LV2) is now
    implemented and functional (intra-chain only).
  - Instrument plugin bank/program selection was found broken or
    dead in the water, specially on VSTi, now finally fixed again.
  - VST plugin parameter value display on generic form is now
    back in business (were dead regarding value changes).
  - All plugin's provided GUI editors are now honored by being
    popped up first, instead of the usual but good old generic
    plugin form.
  - Long overdue implementation of a dedicated MIDI file player is
    now accessible from the MIDI files widget; one can play the
    whole SMF or just a single track or channel.
  - Update to a newer VeSTige header, probably fixing an old 32 vs. 64
    bit mismatch.
  - Avoid JACK session filenames/paths to be ever shown; also avoid
    all buses ports (re)connections when JACK sessions are (re)loaded,
    given the fact that session management will take care of just that;
    more also, untitled/default session names are now also picked up to
    match current LADISH project name, obviously given by LADISH_PROJECT_NAME
    environment variable, whenever present (as suggested by Nedko Ardaunov).
  - Paste-repeat floating selection has been fixed (was showing only the
    last repeated selection).
  - Coherence of tempo changes on audio and MIDI clips, whether automatic
    time-stretching is in effect, has been slightly improved, hopefully fixed.
  - Bold attempt to get linked (aka. ref-counted) audio and MIDI
    clips into practice (EXPERIMENTAL).
  - Main track view now showing all clips above the grid.
  - Added support for both new and older (deprecated URI) lv2_external_ui
    extension (by Nedko Ardaunov).
  - Following yet another great idea, and implementation, by Holger
    Dehnhardt, who already brought us the new aux-send insert plugin,
    thanks again, the so-called direct access control option is now
    featured for any plugin parameter right from plugin listings eg. mixer strips.
  - General resource consumption and management has been slightly
    improved, due to internal buses allocation optimization.
  - Fixed nasty crash-bug that was severely affecting all sessions
    that had at least one insert (pseudo-)plugin on any audio input bus.
  - All automation curve nodes are now relocated whenever disparate
    session sample-rate is detected on load.
  - New aux-send/insert pseudo-plugin is now introduced, allowing to
    route any track audio output to any other audio output bus
    besides the nominal one -- thanks to an original implementation from Holger Dehnhardt.
  - New immediate edit/loop-range settings from current clip extents,
    accessible on the main menu (Clip/Range Set, Loop Set) and from
    MIDI clip editor menu as well (File/Range Set, Loop Set).
  - MIDI Names XML files (*.midnam) may now be imported into MIDI
    instrument definitions. (EXPERIMENTAL)
  - Avoid cursor reset while editing MIDI events list (fixes bug #3380259,
    reported by Frank Neumann).
  - Just some typos fixing (patch #3378382 by c-korn).
  - Track view automation curve editing mode has been slightly fixed,
    now allowing for other previously existing point-and-click mouse operations.
  - Default automation curve mode is now preserved (following a
    suggestion by Alexandre Prokoudine, thanks).
* Fri Aug  5 2011 mseben@gmail.com
- update to 0.5.0
  - MIDI controller learn/catch-up sees the way in:
    MIDI controller changes are now only effective
    after catching-up with their respective program
    parameters, avoiding abrupt jumps and keeping a
    safe and continuous behavior. (EXPERIMENTAL)
  - Track/Height menu is now featured, giving access
    to Increase, Decrease or Reset the current track
    height.
  - All changes to audio gain and panning on tracks
    and buses are now applied following a piece-wise
    linear ramp, reducing the old nasty clicks, pops
    or zipper artifacts that might be awfully audible
    on some situations, most specially on automation.
  - All zooming in/out is now relative to either the
    viewport center or current mouse cursor position
    if found laying inside.
  - TYOQA! the underground sources have emerged:...
    after years in the making, track automation, or
    dynamic curves as some like to call, is finally
    a reality, tricky but real ;)
  - Audio clip anti-glitch/ramp-smoothing effect is
    now slightly independent of current buffer-size
    period (mitigating bug #3338113 effect).
  - Once buried under the Edit menu, Clip menu has
    been finally promoted to top main menu.
  - Debugging stacktrace now applies to all working
    threads.
  - Fixed muted loop playback on audio clips ending
    coincidentally with the loop-turn/end point.
  - Old/deprecated JACK port latency support added
    to audio recording latency compensation.
  - Audio clip merge/export lock-ups now untangled
    (fixes bug #3308998).
  - LV2 extension headers update.
  - Fixed configure of newer LV2 host implementation
    stack (LILV) when older (SLV2) is not present.
- see http://qtractor.sourceforge.net/qtractor-downloads.html
  for all changes since 0.4.7
* Sun Oct  3 2010 davejplater@gmail.com
- Applied patch - qtractor-0.4.7.1-1.patch from upstream to fix 11.2
  build.
* Sat Oct  2 2010 davejplater@gmail.com
- Update to version 0.4.7
- Upstream changes are too numerous to list for changes go to
  http://kde-apps.org/content/show.php/Qtractor?content=56325
* Wed Jun 16 2010 davejplater@gmail.com
- Update to version 0.4.6
- Introducing a non-painting edit sub-mode on the MIDI clip
  editor's piano-roll (see Edit/Select Mode/Edit Draw menu).
- The MIDI clip editor (aka piano-roll) is now a lot more
  quiet about saving its own dirty content, delegating all
  salvage questions to main session control.
- Don't show session restart message box when changing JACK
  transport mode option anymore.
- Dedicated MIDI control bus switching fixed. Was closing
  the wrong bus eventually and crashing the whole show with
  it (fixes bug #2989590).
- MIDI bank/program backout has been corrected on MIDI track
  properties dialog rejection (ie. user cancellation).
- MIDI bank select method has been corrected for tracks with
  no instrument defined (probably fixing bug #2987071).
- LV2 UI Instance and Data Access extension support added;
  reduce LV2 external UI parameter value update flickering.
- JACK session infrastructure support. (EXPERIMENTAL)
- Initial widget geometry and visibility persistence logic
  has been slightly revised as much to avoid crash failures
  due to wrong main widget hidden state.
- Initial mixer widget extents are now set reasonably larger.
- General source tree layout and build configuration change.
- See /usr/share/doc/packages/qtractor/ChangeLog for more.
* Mon Jan 25 2010 mseben@novell.com
- updated to version 0.4.5
  - Changing loop points while playback is rolling, with the
    play-head any near, was leaving audio clips out-of-sync.
  - MIDI event list view was missing some selected items with
    the very same onset time, now fixed.
  - When failing to detect a SSE enabled build, the CFLAGS
    variables are now properly restored to their previous
    sane state, preventing all subsequent dependency tests
    from false positives (bug# 565860@bugs.debian.org).
  - MIDI clip editor (aka piano-roll) multiple selection has
    been fixed (again) re. move/paste-snapping consistency.
* Mon Jan 18 2010 mseben@novell.com
- updated to version 0.4.4
  - For all the DSSI plugins that have output control ports,
    a host feedback/update process cycle is now being finally
    provided: all output control ports are now marshaled to
    their respective GUI process, rather often and when found
    open/visible.
  - MIDI clip editor (aka piano-roll) snap-to-beat behavior on
    edit mode is now kind of more like 'filling-in-the-blanks'
    (as Frank Neumann et al. wishes ;)
  - Fixed MIDI clip editor mistake when reverting to initial
    clip length, before closing and discard changes (thanks
    to Frank Neumann, for spotting this one).
  - LADISH Level 1 support has been added: SIGUSR1 signal trap
    just makes it a shortcut to File/Save.
  - Avoid parameter value flickering, due to duplicate command
    invocation, most evident when changing values massively on
    native Linux VSTi plugin editor GUIs (thanks to a detailed
    report on this odd behavior, from Mike of linuxDSP.co.uk).
  - Another TODO item bites the dust: MIDI event list editor,
    now acessible from the MIDI clip editor menu (View/Events)
  - Last used session directory is now made current on startup
    only when no filename is given on the command line (solving
    bug #2920244).
  - Current snap-to-beat setting (time quantization) now affects
    the anchor event only, while dragging, moving and/or pasting
    multiple events over the MIDI clip editor (aka piano-roll).
  - Make anti-glitch audio clip micro fade-in/outs independent
    from current buffer size as much as possible.
  - Audio/MIDI engine drift correction gets really sophisticated,
    with the help of (now old) ALSA MIDI tempo skew facility.
  - Edit/Clip/Import... menu option is now available for expedite
    clip insertion from audio and MIDI file requesters.
  - Set default session directory effective to file's location.
  - Audio track/clip recording process has been target to special
    refactorization across the internal audio engine process cycle,
    in a late attempt to get self-bounce/recording effective and
    working consistently for all track layouts.
  - All session related dialogs are now set to window modality,
    (were set to default application modality before) allowing
    for continued input focus and interaction on all plugin/tool
    windows.
  - An off-by-one nasty old bug fixed in audio clip drawing, was
    causing instant crashes on certain zoom levels of the main
    track view.
  - Graphical MIDI clip representation regarding note/pitch range is
    now kept as much as possible across clip edits (cut, copy, paste,
    drag, move, delete, etc.)
  - LV2 plug-in hosting has finally come into actual implementation;
    only some and the most basic LV2 plug-in features are supported
    at the moment; probably there's no big advantage against the old
    LADSPA ones; there's some support for external UIs though; also,
    LV2 MIDI/Event bare-bones support is included but chances are it
    won't build nor work right on most of the setups out there. It's
    a WIP host implementation anyways, as is the whole LV2 spec. for
    that matter ;)
  - Connections filter is now reset when widget is shown through the
    View/Connections main menu or toolbar button.
  - Audio bus auto-connection option is now applied when creating or
    updating, newer or existing buses, respectively.
  - Global configuration state is now explicitly saved/committed to
    disk whenever View/Options... dialog changes are applied or when
    a session is loaded or saved.
  - Audio ramping spin-locking makes its smooth stuff, in an attempt
    to reduce glitching and crackling when editing (due to its own
    pseudo spin-locking) and toggling playback states.
  - JACK Transport, MMC Device, and MIDI Song Position pointer (SPP)
    control modes are now made optional (View/Options...), allowing
    for discretionary configuration: None/Disabled, Slave/Input,
    Master/Output or Full/Duplex (default).
  - Session files may now be dragged and dropped over the main track
    view and get loaded for business as usual (once quietly ignored).
  - In an attempt to mitigate potential stack corruption and sudden
    crashes, old commented out session pseudo-locks are now back in
    business while executing clip editing commands (cut, paste, drag,
    move, insert, delete) and playback is currently rolling.
  - Adjusted first-time application window size to fit into 800x600
    screen size and with reasonable initial dockables layout.
  - Avoid duplicate snap-to-grid effect when changing the length of
    MIDI clip editor events across non-zero clip offsets (after a
    glitch reported by Ralf Mardorf).
  - Late audio track processing optimization, suppressing all plugin,
    mixer and monitor pass-through activity when given track is muted,
    either explicitly or implicitly (ie. other track is in solo state).
  - Entering System Exclusive events (SysEx) on the MIDI clip editor
    (aka matrix/piano-roll widget), yet something not fully supported
    anyway, even though allowed in edit mode, doesn't crash the whole
    damn thing anymore, while saving the clip to a file.
  - Strict aliasing avoidance, with plain and demanded use of 'union',
    as much as to stop nagging warnings from gcc >= 4.4.1 (last seen
    on src/qtractorMidiEvent.h hackery).
  - Visual correct play-head position while changing zoom levels,
    applicable to both main track and MIDI clip editor views.
* Thu Nov  5 2009 mseben@novell.com
- updated to 0.4.3
  * External preset files are not removed nor deleted from the file-system anymore.
  * Connections support for UTF-8 encoded client/port names.
  * Force track and clip properties dialog widget to be modal as it should from their beginning dawn.
  * Audio effect send/return aux. inserts are implemented as special pseudo-plugins (Plugins/Inserts).
  * Reset play-head position on auto-backward and keep playback rolling when continue past end transport option is not set.
  * MIDI clip editor (aka piano-roll/matrix aditor) gets better on the virtual piano keyboard eye-candy side of things ;).
  * Plugins are now also referenced by label, avoiding plugin index clash/misses eg. when plugin object file/path changes or is moved externally.
  * Keyboard focus is now cleared/reset from the main toolbar time and tempo spin-boxes when editing gets finished (eg. Enter key is pressed).
  * First audio metronome beat/bar now played back correctly (fixes bug #2841437).
  * Client to/from port (dis)connections now found consistent as good ol'QjackCtl behavior (fixes bug #2834657).
  * All dirty open MIDI clip editors are now prompted to save before the main application closes (fixes bug #2835516).
  * Mixer level meters get their long deserved gradient look.
  * Fixed any ghost clip selections that were haunting the main track view, specially after undo/redo.
  * Increased tolerance on reading corrupt MIDI files (SMF).
  * A MIDI SysEx manager is being finally introduced, in some primordial rather basic form though.
  * A default MIDI instrument name may now be assigned to any MIDI output bus (see View/Buses.../MIDI).
  * More legacy headers, stdio.h and stdlib.h, are yet again necessary to build with gcc/g++ >= 4.4 (as patch noted by Alexis Ballier on Gentoo bug report #274168, thanks).
  * Bus manager dialog (View/Buses...) gets new columns on the left pane buses list as for displaying number of channels and bus mode.
  * Crash when updating bus probably fixed (bug #2811630).
  * Fixed glitch displaying beat snap/grid lines on MIDI clip editor, incidental to clips located at absolute zero time.
  * Overlapped MIDI clips were rendering garbled note events to DSSI/VSTi plugins, now fixed.
  * New MIDI Playback/Queue timer (resolution) option is now available (see View/Options.../MIDI).
  * MIDI instrument definitions may now be imported from plain SoundFont files.
* Tue Oct  6 2009 mseben@novell.com
- updated to 0.4.2
  * External preset files are not removed nor deleted from the file-system anymore.
  * Connections support for UTF-8 encoded client/port names.
  * Force track and clip properties dialog widget to be modal as it should from their beginning dawn.
  * Audio effect send/return aux. inserts are implemented as special pseudo-plugins (Plugins/Inserts).
  * Reset play-head position on auto-backward and keep playback rolling when continue past end transport option is not set.
  * MIDI clip editor (aka piano-roll/matrix aditor) gets better on the virtual piano keyboard eye-candy side of things ;).
  * Plugins are now also referenced by label, avoiding plugin index clash/misses eg.
  when plugin object file/path changes or is moved externally.
  * Keyboard focus is now cleared/reset from the main toolbar time and tempo spin-boxes
  when editing gets finished (eg. Enter key is pressed).
  * First audio metronome beat/bar now played back correctly (fixes bug #2841437).
  * Client to/from port (dis)connections now found consistent as good ol'QjackCtl behavior (fixes bug #2834657).
  * All dirty open MIDI clip editors are now prompted to save before the main application closes (fixes bug #2835516).
  * Mixer level meters get their long deserved gradient look.
  * Fixed any ghost clip selections that were haunting the main track view, specially after undo/redo.
  * Increased tolerance on reading corrupt MIDI files (SMF).
  * A MIDI SysEx manager is being finally introduced, in some primordial rather basic form though. MIDI System
  Exclusive (SysEx) event strings may now be freely assigned to MIDI output buses only, allowing for proper
  setup of external outboard MIDI equipment. Each bus may have an unlimited SysEx queue that gets sent out on every
  connection change (see View/Buses.../MIDI/SysEx...).
  * A default MIDI instrument name may now be assigned to any MIDI output bus (see View/Buses.../MIDI).
  * More legacy headers, stdio.h and stdlib.h, are yet again necessary to build with gcc/g++ >= 4.4 (as patch noted
  by Alexis Ballier on Gentoo bug report #274168, thanks).
  * Bus manager dialog (View/Buses...) gets new columns on the left pane buses list
  as for displaying number of channels and bus mode.
  * Crash when updating bus probably fixed (bug #2811630).
  * Fixed glitch displaying beat snap/grid lines on MIDI clip editor, incidental to clips located at absolute zero time.
  * Overlapped MIDI clips were rendering garbled note events to DSSI/VSTi plugins, now fixed.
  * New MIDI Playback/Queue timer (resolution) option is now available (see View/Options.../MIDI).
  * MIDI instrument definitions may now be imported from plain SoundFont files.
* Mon Aug 31 2009 mseben@suse.cz
- added jack to Requires section
* Fri Jul 31 2009 mseben@suse.cz
- added librubberband2-devel to buildrequires (for 11.2 and higher)
* Fri Jul 24 2009 tiwai@suse.de
- fix buildrequires: dssi -> dssi-devel
* Tue Jun  9 2009 mseben@suse.cz
- updated to version 0.4.2
  * The MIDI clip editor (piano-roll/matrix editor), the main track
  view as well, have been subject to usability fixing.
  * MIDI tracks channel bank/program and controller stuff are now
  only issued when the respective bus connections have changed,
  seldom on every playback start.
  * MIDI controller mapping infrastructure, with file based
  configuration management (see View/Controllers...), is now
  in place, following an original contribution from gizzmo aka Mathias Krause.
  * Plugin chain buffer reset on playback start/stop is not
  guarded by a momentary plugin de/activation anymore.
  * Clip export may now be applied to multiple clips, sharing
  common refactored code and same semantics as merging of
  current selected clips.
  * Improved, may be just fixed yet again, audio track export
  synchronization and reliability.
  * Clip merge is now featured both for audio and MIDI tracks.
  * Fixed the precision of multi-clip final positioning as result
  of drag/move and paste operations in main track view (as in bug #2741611).
  * MIDI track program number is now listed in 1-128 range.
  * MIDI editor snap grid lines get slight different color
  then regular beat divisions.
  * Reset local tempo map cursor on newer MIDI file imports
  in a tentative to fix incidental but random crashes.
* Thu May  7 2009 prusnak@suse.cz
- updated to 0.4.1
* Wed Nov 26 2008 tiwai@suse.de
- updated to version 0.2.2:
  * too much to list updates since 0.0.8...
* Wed Nov 28 2007 tiwai@suse.de
- updated to version 0.0.8.762
- fix build with gcc 4.3
- build properly with RPM_OPT_FLAGS
* Tue Sep 18 2007 prusnak@suse.cz
- created package (initial version 0.0.5.702)
